.infer_case_from_vocab: Determine Vocabulary Casedness
Description
Determine whether or not a wordpiece vocabulary is case-sensitive.
Usage
.infer_case_from_vocab(vocab)
Arguments
vocab
The vocabulary as a character vector.
Value
TRUE if the vocabulary is cased, FALSE if uncased.
Details
If none of the tokens in the vocabulary start with a capital letter, it will
be assumed to be uncased. Note that tokens like "\[CLS\]" contain uppercase
letters, but don't start with uppercase letters.